@@ -2,8 +2,9 @@ from peerberrypy.endpoints import ENDPOINTS
 from peerberrypy.request_handler import RequestHandler
 from peerberrypy.exceptions import InvalidCredentials, InvalidPeriodicity, InsufficientFunds, InvalidSort, InvalidType
 from peerberrypy.constants import CONSTANTS
-from datetime import date
+from peerberrypy.utils import Utils
 from typing import Union
+from datetime import date
 import pandas as pd
 import warnings
 import pyotp
@@ -41,9 +42,7 @@ class API:
         :return: Basic information, accounts & balance information
         """
 
-        return self.__session.request(
-            url=ENDPOINTS.PROFILE_URI,
-        )
+        return Utils.parse_peerberry_items(self.__session.request(url=ENDPOINTS.PROFILE_URI))
 
     def get_loyalty_tier(self) -> dict:
         """
@@ -58,10 +57,10 @@ class API:
         unlocked_tiers = list(filter(lambda obj: obj['locked'] is False, response['items']))
 
         # Get the highest unlocked tier
-        top_available_tier = unlocked_tiers[-1]
+        top_available_tier = unlocked_tiers[-1] if len(unlocked_tiers) > 0 else None
 
         return {
-            'tier': top_available_tier['title'].rstrip(),
+            'tier': top_available_tier['title'].rstrip() if top_available_tier else None,
             'extra_return': f'{top_available_tier["percent"]}%',
             'max_amount': top_available_tier['maxAmount'],
             'min_amount': top_available_tier['minAmount'],
@@ -72,8 +71,10 @@ class API:
         :return: Available balance, total invested, total profit, current investments, net annual return, etc.
         """
 
-        return self.__session.request(
-            url=ENDPOINTS.OVERVIEW_URI,
+        return Utils.parse_peerberry_items(
+            self.__session.request(
+                url=ENDPOINTS.OVERVIEW_URI,
+            )
         )
 
     def get_profit_overview(
@@ -107,9 +108,7 @@ class API:
         :return: Percentage of funds in current loans and late loans (In 1-15, 16-30, and 31-60 day intervals)
         """
 
-        return self.__session.request(
-            url=ENDPOINTS.INVESTMENTS_STATUS_URI,
-        )
+        return Utils.parse_peerberry_items(self.__session.request(url=ENDPOINTS.INVESTMENTS_STATUS_URI))
 
     def get_loans(
             self,
@@ -125,8 +124,8 @@ class API:
             loan_types: list = None,
             sort: str = 'loan_amount',
             ascending_sort: bool = False,
-            group_guarantee: bool = True,
-            exclude_invested_loans: bool = True,
+            group_guarantee: bool = None,
+            exclude_invested_loans: bool = None,
             raw: bool = False,
     ) -> Union[pd.DataFrame, list]:
         """
@@ -180,11 +179,11 @@ class API:
         if min_available_amount is not None:
             loan_params['minRemainingAmount'] = min_available_amount
 
-        if group_guarantee:
-            loan_params['groupGuarantee'] = 1
+        if group_guarantee is not None:
+            loan_params['groupGuarantee'] = int(group_guarantee)
 
-        if exclude_invested_loans:
-            loan_params['hideInvested'] = 1
+        if exclude_invested_loans is not None:
+            loan_params['hideInvested'] = int(exclude_invested_loans)
 
         # Add country filters to query parameters
         if countries:
@@ -197,7 +196,7 @@ class API:
 
                 if isinstance(id_, list):
                     for sub_id, originator_id in enumerate(id_):
-                        loan_params[f'loanOriginators[{idx+sub_id}]'] = originator_id
+                        loan_params[f'loanOriginators[{idx + sub_id}]'] = originator_id
 
                     continue
 
@@ -211,12 +210,17 @@ class API:
         loans = []
 
         for _ in range(math.ceil(quantity / 40)):
+            print('test --->', loan_params)
+
             loans_data = self.__session.request(
                 url=ENDPOINTS.LOANS_URI,
                 params=loan_params,
             )['data']
 
-            # Extend current loan list with new loans
+            if len(loans_data) == 0:
+                break
+
+                # Extend current loan list with new loans
             loans.extend(loans_data)
 
             loan_params['offset'] += 40
@@ -320,10 +324,16 @@ class API:
         if quantity <= 0:
             raise ValueError('You need to fetch at least 1 investment.')
 
-        if sort not in CONSTANTS.LOAN_SORT_TYPES:
-            raise InvalidSort(f'Loans can only be sorted by: {", ".join(CONSTANTS.LOAN_SORT_TYPES)}')
+        sort_types = CONSTANTS.CURRENT_INVESTMENT_SORT_TYPES if current else CONSTANTS.FINISHED_INVESTMENT_SORT_TYPES
 
-        sort = CONSTANTS.LOAN_SORT_TYPES[sort]
+        if sort not in CONSTANTS.LOAN_SORT_TYPES:
+            raise InvalidSort(f'Loans can only be sorted by: {", ".join(sort_types)}')
+
+        if current:
+            sort = sort_types[sort]
+
+        else:
+            sort = sort_types[sort]
 
         investment_params = {
             'sort': sort if ascending_sort else f'-{sort}',
@@ -639,3 +649,11 @@ class API:
         self.__session.remove_header('Authorization')
 
         return 'Successfully logged out.'
+
+    @staticmethod
+    def get_countries() -> dict:
+        return CONSTANTS.get_countries()
+
+    @staticmethod
+    def get_originators() -> dict:
+        return CONSTANTS.get_originators()
