@@ -42,6 +42,21 @@ class CONSTANTS:
         'loan_amount': 'availableToInvest',
     }
 
+    CURRENT_INVESTMENT_SORT_TYPES = {
+        'purchase_date': 'dateOfPurchcase',
+        'interest_rate': 'interestRate',
+        'loan_amount': 'amount',
+        'estimated_final_payment_date': 'estimatedFinalPaymentDate',
+    }
+
+    FINISHED_INVESTMENT_SORT_TYPES = {
+        'final_payment_date': 'finishedAt',
+        'purchase_date': 'dateOfPurchcase',
+        'interest_rate': 'interestRate',
+        'loan_amount': 'amount',
+        'estimated_final_payment_date': 'estimatedFinalPaymentDate',
+    }
+
     LOAN_EXPORT_SORT_TYPES = {
         'date_of_purchase': 'Date of purchase',
         'interest_rate': 'Interest rate',
@@ -68,10 +83,28 @@ class CONSTANTS:
 
         return cls.GLOBALS
 
+    @classmethod
+    def get_countries(cls) -> dict:
+        if cls.COUNTRIES_ISO is None:
+            cls.COUNTRIES_ISO = dict(
+                map(lambda cnt: (cnt['title'].strip(), cnt['id']), cls.get_globals()['countries'])
+            )
+
+        return cls.COUNTRIES_ISO
+
+    @classmethod
+    def get_originators(cls) -> dict:
+        if cls.ORIGINATORS_ID is None:
+            cls.ORIGINATORS_ID = dict(
+                map(lambda org: (org['title'].strip(), org['id']), cls.get_globals()['originators'])
+            )
+
+        return cls.ORIGINATORS_ID
+
     @classmethod
     def get_country_iso(cls, country: str) -> int:
         if cls.COUNTRIES_ISO is None:
-            cls.COUNTRIES_ISO = dict(map(lambda cnt: (cnt['title'], cnt['id']), cls.get_globals()['countries']))
+            cls.COUNTRIES_ISO = cls.get_countries()
 
         if country not in cls.COUNTRIES_ISO:
             raise ValueError(
@@ -83,7 +116,7 @@ class CONSTANTS:
     @classmethod
     def get_originator(cls, originator: str) -> int:
         if cls.ORIGINATORS_ID is None:
-            cls.ORIGINATORS_ID = dict(map(lambda org: (org['title'], org['id']), cls.get_globals()['originators']))
+            cls.ORIGINATORS_ID = cls.get_originators()
 
         if originator not in cls.ORIGINATORS_ID:
             raise ValueError(
